Struct Dfltintr
#[repr(transparent)]pub struct Dfltintr(pub u32);Expand description
This register is used to the integrator (INT) settings.
Tuple Fields
0: u32Implementations
impl Dfltintr
impl Dfltintr
pub const fn intdiv(&self) -> Intdiv
pub const fn intdiv(&self) -> Intdiv
Integrator output division Set and cleared by software. This bit is used to rescale the signal at the integrator output in order keep the data width lower than 24 bits. - 00: The integrator data outputs are divided by 128 (Default value) - 01: The integrator data outputs are divided by 32 - 10: The integrator data outputs are divided by 4 - 11: The integrator data outputs are not divided This field can be write-protected, please refer to Section 1.4.15: Register protection for details.
pub const fn set_intdiv(&mut self, val: Intdiv)
pub const fn set_intdiv(&mut self, val: Intdiv)
Integrator output division Set and cleared by software. This bit is used to rescale the signal at the integrator output in order keep the data width lower than 24 bits. - 00: The integrator data outputs are divided by 128 (Default value) - 01: The integrator data outputs are divided by 32 - 10: The integrator data outputs are divided by 4 - 11: The integrator data outputs are not divided This field can be write-protected, please refer to Section 1.4.15: Register protection for details.
pub const fn intval(&self) -> u8
pub const fn intval(&self) -> u8
Integration value selection Set and cleared by software. This field is used to select the integration value. - 0: The integration value is 1, meaning bypass mode (default after reset) - 1: The integration value is 2 - 2: The integration value is 3 … - 127: The integration value is 128 This field can be write-protected, please refer to Section 1.4.15: Register protection for details.
pub const fn set_intval(&mut self, val: u8)
pub const fn set_intval(&mut self, val: u8)
Integration value selection Set and cleared by software. This field is used to select the integration value. - 0: The integration value is 1, meaning bypass mode (default after reset) - 1: The integration value is 2 - 2: The integration value is 3 … - 127: The integration value is 128 This field can be write-protected, please refer to Section 1.4.15: Register protection for details.